@@ -39,10 +39,13 @@ public:
     void setMovable(bool canMove);
     void moveMeTo(const QPointF &location);
     static int moveCount();
+    static void setMoveCount(const int count);
     static void resetMoveCount();
     void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget);
     void setPieceNumber(const int pieceNumber);
     int pieceNumber() const;
+    void setDrawNumber(bool value);
+    bool drawNumber() const;
 
 protected:
     void mousePressEvent(QGraphicsSceneMouseEvent *event);
@@ -55,5 +58,6 @@ private:
     QPropertyAnimation *moveAnimation_;
     static int moveCount_;
     int pieceNumber_;
+    bool drawNumber_;
 };
 #endif
